define("wagby/portlet/ModernCalendarPortlet", [
  "dojo/_base/declare",
  "dojo/date",
  "dojo/date/locale",
  "dojo/date/stamp",
  "dojo/dom-construct",
  "dojo/request",
  "dojo/store/Memory",
  "dojo/store/Observable", 
  "dojox/calendar/Calendar", 
  "wagby/portlet/BasePortlet"
], function(declare, date, locale, stamp, domConstruct, request, Memory, Observable, Calendar, BasePortlet) {
  return declare("wagby.portlet.ModernCalendarPortlet", [BasePortlet], {
    firstDayOfWeek: 0,

    postCreate: function() {
      this.setFirstDayOfWeek();
      this.inherited(arguments);
    },

    setFirstDayOfWeek: function() {
      var that = this;
      this.getUserPreference(function(preference) {
        if (!preference || !preference.item) {
          return;
        }
        let calendarFirstDayOfWeek = preference.item.find((obj, idx, arr) => {
          return obj.key === "__jfc_calendarFirstDayOfWeek";
        });
        if (!calendarFirstDayOfWeek) {
          return;
        }
        that.firstDayOfWeek = parseInt(calendarFirstDayOfWeek.content, 10);
      });
    },

    getUserPreference: function(callback) {
      var that = this;
      request("rest/session", {
        headers: {
          'X-Wagby-RESTAPIVersion': "v2",
        },
        handleAs: "json",
        withCredentials: true,
      }).then(function(data) {
        callback(data.preference);
      }, function(err) {
        console.error(err);
      });
    },

    getCalendarOption: function() {
      // スクリプト欄にカレンダの設定を返す関数があれば実行する
      if (!jfcCalendarPortletOption) {
        return {};
      }
      return jfcCalendarPortletOption();
    },

    showContents: function() {
      this.inherited(arguments);
      this.createCalendar();
    },

    createCalendar: function() {
      // カレンダのオプションをカレンダポートレットのスクリプト欄から取得する
      var calendarOption = this.getCalendarOption();
      calendarOption.firstDayOfWeek = this.firstDayOfWeek;

      // カレンダの表示サイズをポートレットのサイズに設定する
      var width = this.portletWidth - 25;
      var height = this.portletHeight - 60;
      // カレンダ生成
      try {
        this.calendar = ModernCalendarUtil.createCalendar({
          id: this.contentsArea,
          modelId: this.modelId,
          dateInterval: calendarOption.dateInterval || "week",
          minHours: calendarOption.minHours === undefined ? 8 : calendarOption.minHours,
          maxHours: calendarOption.maxHours === undefined ? 24 : calendarOption.maxHours,
          firstDayOfWeek: calendarOption.firstDayOfWeek === undefined ? 0 : calendarOption.firstDayOfWeek,
          width: width + "px",
          height: height + "px",
          domainURL: this.portletDomainURL,
        });
        // ポートレットではデフォルトはカレンダ編集不可
        this.calendar.set("editable", calendarOption.editable === undefined ? false : calendarOption.editable);
        this.calendar.columnView.columnHeaderDatePattern = 'MM/dd';
      } catch(e) {
        console.error(e);
      }
    }
  });
});
